[Zope-Checkins] CVS: Packages/Zope/Startup - zopectl.py:1.3.2.10

Stefan H. Holek stefan at epy.co.at
Tue Sep 28 06:07:05 EDT 2004


Update of /cvs-repository/Packages/Zope/Startup
In directory cvs.zope.org:/tmp/cvs-serv5951/lib/python/Zope/Startup

Modified Files:
      Tag: Zope-2_7-branch
	zopectl.py 
Log Message:
When installed, test.py lives in $ZOPE_HOME/bin.


=== Packages/Zope/Startup/zopectl.py 1.3.2.9 => 1.3.2.10 ===
--- Packages/Zope/Startup/zopectl.py:1.3.2.9	Fri Sep 17 05:50:48 2004
+++ Packages/Zope/Startup/zopectl.py	Tue Sep 28 06:07:04 2004
@@ -215,11 +215,7 @@
     def do_test(self, arg):
         args = filter(None, arg.split(' '))
 
-        if not args:
-            print "usage: test [args]+"
-            return
-
-        # test.py lives in $ZOPE_HOME!
+        # test.py lives in $ZOPE_HOME/bin
         zope_home = os.getenv('ZOPE_HOME')
 
         if zope_home is None:
@@ -230,9 +226,15 @@
             print "Can't find test.py -- set ZOPE_HOME before running!"
             return
 
-        script = os.path.join(zope_home, 'test.py')
+        script = os.path.join(zope_home, 'bin', 'test.py')
         assert os.path.exists(script)
 
+        # If --libdir is not supplied, use $INSTANCE_HOME/Products
+        # (rather than $INSTANCE_HOME/lib/python)
+        if '--libdir' not in args:
+            args.insert(0, 'Products')
+            args.insert(0, '--libdir')
+
         # Supply our config file by default.
         if '--config-file' not in args and '-C' not in args:
             args.insert(0, self.options.configfile)
@@ -242,12 +244,6 @@
         if '-v' not in args and '-q' not in args:
             args.insert(0, '-v')
 
-        # If --libdir is not supplied, use $INSTANCE_HOME/Products
-        # (rather than $INSTANCE_HOME/lib/python)
-        if '--libdir' not in args:
-            args.insert(0, 'Products')
-            args.insert(0, '--libdir')
-
         args.insert(0, script)
 
         cmdline = ' '.join([self.options.python] + args)
@@ -256,7 +252,7 @@
 
     def help_test(self):
         print "test [args]+ -- run unit / functional tests."
-        print "                See $ZOPE_HOME/test.py for syntax."
+        print "                See $ZOPE_HOME/bin/test.py --help for syntax."
 
 
 def main(args=None):



More information about the Zope-Checkins mailing list